@@ -1,7 +1,10 @@
-## ----setup, include=FALSE-----------------------------------------------------
-knitr::opts_chunk$set(echo = TRUE)
+## ----include = FALSE----------------------------------------------------------
+knitr::opts_chunk$set(
+  collapse = TRUE,
+  comment = "#>"
+)
 
-## -----------------------------------------------------------------------------
+## ----setup--------------------------------------------------------------------
 library(lrstat)
 
 ## -----------------------------------------------------------------------------
